@@ -102,11 +102,13 @@ var reportElementMF = {
 		util.disableE(['remf:add_remove_btn', 'remf:move_up_btn', 'remf:move_down_btn']);
 		
 		
-		// Get a referenece to the active reportElementDb type and columns
+		// Get a reference to the active reportElementDb type and columns
 		var metaType = reportElement.activeMetaType;
 		var metaTypeLabel = reports.reportElementMetaTypesDb[util.h(metaType)].label;
 		var reportElementType = reportElement.activeReportElementType;
 		var reportElementDb = reportElement.activeReportElementDbs[reportElementType];
+
+		// util.showObject(reportElementDb);
 		
 		// alert('metaTypeLabel: ' + metaTypeLabel);
 		
@@ -139,6 +141,9 @@ var reportElementMF = {
 	saveFields: function() {
 		
 		var allFieldsDb = reportElementMF.allFieldsDb;
+
+		// util.showObject(allFieldsDb);
+
 		var activeFieldsDb = reportElementMF.activeFieldsDb;
 		var firstTextReportField = '';
 		var columns = [];
@@ -161,6 +166,7 @@ var reportElementMF = {
 					
 					columnItem.show_percent_column = item.showPercentColumn;
 					columnItem.show_bar_column = item.showBarColumn;
+					columnItem.show_graph = item.showGraph;
 				}
 			}
 			else if (firstTextReportField == '') {
@@ -170,15 +176,18 @@ var reportElementMF = {
 			
 			columns[i] = columnItem;
 		}
-		
-		
+
 		if ((!isOverview && firstTextReportField != '') ||
 			(isOverview && columns.length > 0)) {
 			
 			var reportElementDb = reportElementMF.reportElementDb;
 			reportElementDb.columns = columns;
-			
+
 			// Re-init the reportElementDb
+			// Save changes to reportElementDb before reapplying creControl.init()
+			// or all already done changes to the report element are lost!
+			creControl.saveChanges();
+
 			var obj = {};
 			obj.defaultTabId = reportElementMF.defaultTabId;
 			creControl.init(reportElementDb, obj);
@@ -705,6 +714,7 @@ var reportElementMF = {
 			if (isAggregatingField) {
 				obj.showPercentColumn = false;
 				obj.showBarColumn = false;
+				obj.showGraph = false;
 			}
 			
 			allFieldsDb[allFieldsDbLen] = obj;
@@ -721,7 +731,7 @@ var reportElementMF = {
 		var allFieldsDb = [];
 		
 		// KHP 04/Oct/2010 - Create a tempColumns object,
-		// it is used to verfy if all columns exist in allFieldsDb.
+		// it is used to verify if all columns exist in allFieldsDb.
 		// If a column is missing for whatever reason in allFieldsDb 
 		// then we must add it.
 		var tempColumns = util.cloneObject(columns);
@@ -817,6 +827,7 @@ var reportElementMF = {
 				if (!isOverview && allFieldsItem.isAggregatingField) {
 					allFieldsItem.showPercentColumn = column.show_percent_column;
 					allFieldsItem.showBarColumn = column.show_bar_column;
+					allFieldsItem.showGraph = column.show_graph;
 				}
 			}
 		}
