@@ -2631,9 +2631,14 @@ var newProfileWizard = function() {
 
 			var theSnapon = snapons[i];
 			var logFormatSnaponName = theSnapon.logFormatSnaponName;
+
+			// 2012-10-02 - GMF - Get the snapon instance name
+			var logFormatSnaponInstanceName = theSnapon.logFormatSnaponInstanceName;
+
 			var parametersForm = theSnapon.parametersForm;
 
-            var path = 'volatile.new_profile.snapons.' + logFormatSnaponName;
+			// 2012-10-02 - GMF - Use the instannce name (not the snapon name) to set attach=true
+            var path = 'volatile.new_profile.snapons.' + logFormatSnaponInstanceName;
 
             dat += path + '.attach=' + theSnapon.attach + '&';
 
