@@ -34,49 +34,83 @@ var report = {
 		util.initBreadCrumbNav();
 		
 		var reportElements = reportInfo.reportElements;
+		var maxReportElements = reportElements.length;
 		
 		// create a hash to access the report elements by sid (short_report_element_id)
 		util.createHash(reportElements, 'sid');
 		
 		// create reportFields hash
 		util.createHash(reportInfo.queryFieldsDb, 'name');
-		
-		
-		//
+
+		// util.showObject(reportElements);
+
+
+		// Check and set report elements height
+		report.initReportElementsHeight(reportElements, maxReportElements);
+
 		//
 		// init report elements
 		//
-		//
 		
-		for (var i = 0; i < reportElements.length; i++) {
+		for (var i = 0; i < maxReportElements; i++) {
 			
 			var o = reportElements[i];
+			// util.showObject(o);
 			var reportElementId = o.id;
 			var shortReportElementId = o.sid;
 			var reportElementType = o.reportElementType;
-			
+			var isLogDetail = reportElementType == 'log_detail';
+
+
+			//
+			// init reportLink
+			//
+
+			var reportLink = o.reportLink;
+			if (reportLink != '') {
+				YE.addListener(shortReportElementId + ':report_link', 'click', newReport.getReportByReportLink);
+				YE.addListener(shortReportElementId + ':report_link', 'mousedown', zoomControl.zoomSilent);
+			}
+
 			//
 			//
 			// init rows
 			//
 			//
+
+			// isUnknownTotalRows and numberOfRowsInTable are relevant for log_detail only
+			var isUnknownTotalRows = false;
+			var numberOfRowsInTable = 0;
+
 			
-			if (reportElementType == 'table' || reportElementType == 'log_detail') {
+			if (reportElementType == 'table' || isLogDetail) {
 				
 				report.isTableOrLogDetailReportElement = true;
+
+				if (isLogDetail && o.hasOwnProperty('isUnknownTotalRows')) {
+					isUnknownTotalRows = o.isUnknownTotalRows;
+					numberOfRowsInTable = o.numberOfRowsInTable;
+				}
+
+				// Ignore totalRows value if isUnknownTotalRows is true. In this case we allow to set any row number
+				// because the total rows number is not accurate.
 				
-				if (o.totalRows > 0) {
-				
-				 	if (o.totalRows > 10) {
-				 		
-						report.rowNumbers.build(shortReportElementId, reportElementType, o.startingRow, o.endingRow, o.numberOfRows, o.totalRows);
-					}
-					
+				if (o.totalRows > 0 || isUnknownTotalRows) {
+
+					report.rowNumbers.init(
+						shortReportElementId,
+						reportElementType,
+						o.startingRow,
+						o.endingRow,
+						o.numberOfRows,
+						o.totalRows,
+						isUnknownTotalRows,
+						numberOfRowsInTable);
+
 					//
 					// init row selection
 					//
-					
-					
+
 					// Assign a single tbody event for row selection, zoom selection and breakdown
 					var tBodyId = shortReportElementId + ':tbody';
 					YE.addListener(tBodyId, 'click', report.rowSelection.rowActivated);
@@ -119,7 +153,15 @@ var report = {
 			else if (reportElementType == 'session_page_paths') {
 				
 				if (o.totalRows > 10) {
-					report.rowNumbers.build(shortReportElementId, reportElementType, 1, o.endingRow, o.endingRow, o.totalRows);
+					report.rowNumbers.init(
+						shortReportElementId,
+						reportElementType,
+						1,
+						o.endingRow,
+						o.endingRow,
+						o.totalRows,
+						isUnknownTotalRows,
+						numberOfRowsInTable);
 				}
 				
 				YE.addListener(shortReportElementId + ':page_path_field', 'keypress', newReport.setPagePathViaKey);
@@ -195,6 +237,133 @@ var report = {
 		// init simple progress
 		report.busyPanel = new util.BusyPanel();
 	},
+
+	initReportElementsHeight: function(reportElements, maxReportElements) {
+
+		// This corrects the report element height if the report contains floated report elements,
+		// i.e. in a dashboard
+
+		var requiresHeightAdjustment = false,
+			reportElementItem,
+			shortReportElementId,
+			reportElementContainer,
+			i;
+
+		// Check if we need to set any height at all.
+		// We must set the height for all report elements, though report elements
+		// like overview compact or tables shouldn't expand the box with the border,
+		// so they will have an invisible box around it.
+
+		for (i = 0; i < maxReportElements; i++) {
+
+			reportElementItem = reportElements[i];
+
+			// util.showObject(reportElementItem);
+
+			// Get report element and save it in
+			// reportElements for later use
+			shortReportElementId = reportElementItem.sid;
+			reportElementContainer = util.getE(shortReportElementId + ':re_container');
+			reportElementItem['reContainerRef'] = reportElementContainer;
+
+			if (reportElementItem.displaySideBySide) {
+				requiresHeightAdjustment = true;
+			}
+		}
+
+		if (requiresHeightAdjustment) {
+			YAHOO.util.Event.addListener(window, 'resize', report.adjustReportElementsHeightOnResize);
+			report.adjustReportElementsHeight();
+		}
+	},
+
+	adjustReportElementsHeightOnResize: function() {
+		setTimeout('report.resetAndAdjustReportElementHeightOnResize()', 400);
+	},
+
+	resetAndAdjustReportElementHeightOnResize: function() {
+
+		// Before we re-adjust the height of the report elements we need
+		// to display them without any specific height settings because
+		// the height could have changed due display properties and constraints.
+
+		var reportElements = reportInfo.reportElements,
+			maxReportElements = reportElements.length,
+			theReportElement,
+			i;
+
+		for (i = 0; i < maxReportElements; i++) {
+
+			// Reset height
+			theReportElement = reportElements[i].reContainerRef;
+			theReportElement.style.height = '';
+		}
+
+		// Re-adjust the height where necessary
+		report.adjustReportElementsHeight();
+	},
+
+	adjustReportElementsHeight: function() {
+
+		var YD = YAHOO.util.Dom;
+
+		var reportElements = reportInfo.reportElements,
+			maxReportElements = reportElements.length,
+			requiresHeightAdjustment = false,
+			reportElementItem,
+			i,
+			j,
+			shortReportElementId,
+			theReportElement,
+			reportElementRegion,
+			activeRow = {
+				top:-1,
+				maxHeight: -1,
+				rowElements: []
+			},
+			numActiveRowItems;
+
+		// Adjust the height per row
+		for (i = 0; i < maxReportElements; i++) {
+
+			reportElementItem = reportElements[i];
+			// shortReportElementId = reportElementItem.sid;
+			// theReportElement = util.getE(shortReportElementId + ':re_container');
+
+			// Get container element reference
+			theReportElement = reportElementItem.reContainerRef;
+			reportElementRegion = YD.getRegion(theReportElement);
+
+			if (reportElementRegion.top == activeRow.top) {
+				// This must be a report element in the same row
+
+				// Set maxHeight
+				if (reportElementRegion.height > activeRow.maxHeight) {
+					activeRow.maxHeight = reportElementRegion.height;
+				}
+
+				// Add theReportElement to activeRow
+				activeRow.rowElements.push(theReportElement);
+			}
+			else {
+				// This must be the first report element of a new row
+
+				// Resize elements of current row
+				numActiveRowItems = activeRow.rowElements.length;
+				if (numActiveRowItems > 1) {
+					for (j = 0; j < numActiveRowItems; j++) {
+						activeRow.rowElements[j].style.height = activeRow.maxHeight + 'px';
+					}
+				}
+
+				// Set/Reset activeRow
+				activeRow.top = reportElementRegion.top;
+				activeRow.maxHeight = reportElementRegion.height;
+				activeRow.rowElements = [];
+				activeRow.rowElements.push(theReportElement);
+			}
+		}
+	},
 	
 	initToolbar: function() {
 		
@@ -499,11 +668,10 @@ var report = {
 			
 			var id = this.id;
 			var dat = id.split(':');
-			var shortReportElementId = dat[1];
+			var shortReportElementId = dat[0];
 			var startingRow = 1;
-			var endingRow = dat[2];
+			var endingRow = this.options[this.selectedIndex].value;
 			var numberOfRows = endingRow;
-			
 			newReport.setRowNumber(shortReportElementId, startingRow, endingRow, numberOfRows);
 		},
 		
@@ -511,22 +679,62 @@ var report = {
 			
 			var id = this.id;
 			var dat = id.split(':');
-			var shortReportElementId = dat[1];
-			var startingRow = dat[2];
-			var endingRow = dat[3];
-			var numberOfRows = reportInfo.reportElements[util.h(shortReportElementId)].numberOfRows;
-			
-			newReport.setRowNumber(shortReportElementId, startingRow, endingRow, numberOfRows);
+			var shortReportElementId = dat[0];
+			var isNext = (dat[1].indexOf('next_rows_btn') != -1);
+
+			var o = reportInfo.reportElements[util.h(shortReportElementId)];
+			var startingRow = o.startingRow;
+			var endingRow = o.endingRow;
+			var numberOfRows = o.numberOfRows;
+			var totalRows = o.totalRows;
+
+			// isUnknownTotalRows and numberOfRowsInTable are relevant for log_detail only
+			var isUnknownTotalRows = false;
+			var numberOfRowsInTable = 0;
+
+			if (o.reportElementType == 'log_detail' && o.hasOwnProperty('isUnknownTotalRows')) {
+				isUnknownTotalRows = o.isUnknownTotalRows;
+				numberOfRowsInTable = o.numberOfRowsInTable;
+			}
+
+			var newStartingRow = -1;
+			var newEndingRow = -1;
+
+
+			if (isNext &&
+				((!isUnknownTotalRows && endingRow < totalRows) ||
+				(isUnknownTotalRows && numberOfRowsInTable > 0))) {
+
+				// Go to next rows
+				newStartingRow = endingRow + 1;
+				newEndingRow = endingRow + numberOfRows;
+
+				if (!isUnknownTotalRows && newEndingRow > totalRows) {
+					// Reset to totalRows
+					newEndingRow = totalRows;
+				}
+			}
+			else if (startingRow != -1) {
+
+				// Go to previous rows
+				newStartingRow = (startingRow - numberOfRows >= 1) ? startingRow - numberOfRows : 1;
+				newEndingRow = startingRow - 1;
+			}
+
+			// Simply ignore clicks if we didn't set a new starting row and ending row
+			if (newStartingRow != -1) {
+				newReport.setRowNumber(shortReportElementId, newStartingRow, newEndingRow, numberOfRows);
+			}
 		},
 			
 		setCustomRowRange: function() {
 			
 			var calleeId = this.id;
 			var dat = calleeId.split(':');
-			var shortReportElementId = dat[1];
+			var shortReportElementId = dat[0];
 			
-			var startingRow = util.getF('custom_row_range:' + shortReportElementId + ':starting_row');
-			var endingRow = util.getF('custom_row_range:' + shortReportElementId + ':ending_row');
+			var startingRow = util.getF(shortReportElementId + ':custom_row_range:starting_row');
+			var endingRow = util.getF(shortReportElementId + ':custom_row_range:ending_row');
 			
 			var isValidRange = false;
 			
@@ -534,9 +742,19 @@ var report = {
 				
 				startingRow = parseInt(startingRow, 10);
 				endingRow = parseInt(endingRow, 10);
-				var totalRows = reportInfo.reportElements[util.h(shortReportElementId)].totalRows;
-				
-				if (startingRow > 0 && startingRow <= endingRow && endingRow <= totalRows) {
+
+				var o = reportInfo.reportElements[util.h(shortReportElementId)];
+
+				var reportElementType = o.reportElementType;
+				var totalRows = o.totalRows;
+				var isUnknownTotalRows = false;
+
+				if (reportElementType == 'log_detail' && o.hasOwnProperty('isUnknownTotalRows')) {
+					isUnknownTotalRows = o.isUnknownTotalRows;
+				}
+
+				// Allow endingRow to exceed totalRows if total rows is an estimate.
+				if (startingRow > 0 && startingRow <= endingRow && (endingRow <= totalRows || isUnknownTotalRows)) {
 					isValidRange = true;
 				}
 			}
@@ -554,183 +772,51 @@ var report = {
 		toggleCustomRowRange: function() {
 			
 			// alert('toggleCustomRowRange()');
-			
 			var calleeId = this.id;
 			var dat = calleeId.split(':');
-			var shortReportElementId = dat[1];
+			var shortReportElementId = dat[0];
 			
-			var element = util.getE('custom_row_range:' + shortReportElementId + ':panel');
-			element.style.display = (element.style.display == 'none') ? 'block' : 'none';
-		},
-		
-		build: function(shortReportElementId, reportElementType, startingRow, endingRow, numberOfRows, totalRows) {
-			
-			var container = util.getE('rows_number_container:' + shortReportElementId);
-			
-			var div = util.createE('div', {paddingTop:'4px', paddingBottom:'4px'}); // Padding must match the containing anchor element padding!
-			
-			var divId = 'custom_row_range:' + shortReportElementId + ':panel';
-			var div2 = util.createE('div', {id:divId, paddingTop:'5px', paddingBottom:'7px', display:'none'});
-	
-			if (reportElementType == 'table' || reportElementType == 'log_detail') {
-				report.rowNumbers.buildPreviousNextButtonsBar(div, shortReportElementId, startingRow, endingRow, numberOfRows, totalRows);
-			}
-			report.rowNumbers.buildNumberButtonsBar(div, shortReportElementId, startingRow, endingRow, totalRows);
-			report.rowNumbers.buildCustomRowRangeBar(div2, shortReportElementId, startingRow, endingRow);
-		
-			util.chainE([container, div, div2]);
-		},
-		
-		buildPreviousNextButtonsBar: function(div, shortReportElementId, startingRow, endingRow, numberOfRows, totalRows) {
-			
-			if (startingRow != 1) {
-				
-				// Add a previous rows button
-				var previousEndingRow = startingRow - 1;
-				var previousStartingRow = (startingRow - numberOfRows >= 1) ? startingRow - numberOfRows : 1;
-				report.rowNumbers.buildPreviousNextButton(div, shortReportElementId, previousStartingRow, previousEndingRow, false);
-			}
-			
-			if (endingRow != totalRows) {
-				
-				// Add a next rows button
-				var nextStartingRow = endingRow + 1;
-				var nextEndingRow = (endingRow + numberOfRows <= totalRows) ? endingRow + numberOfRows : totalRows;
-				report.rowNumbers.buildPreviousNextButton(div, shortReportElementId, nextStartingRow, nextEndingRow, true);
-			}
-			
-			//
-			// Add a spacer
-			//
-			
-			var span = util.createE('span', {paddingRight:'24px'});
-			var spanText = util.createT('&nbsp;');
-			util.chainE(div, span, spanText);
-		},
-		
-		buildPreviousNextButton: function(div, shortReportElementId, startingRow, endingRow, isNext) {
-			
-			var id = 'row_range_btn:' + shortReportElementId + ':' + startingRow + ':' + endingRow;
-			// var title = 'Show row ' + startingRow + ' - ' + endingRow;
-			var title = langVar('lang_stats.row_numbers.show_row_from_to');
-			title = title.replace(/__PARAM__1/, startingRow);
-			title = title.replace(/__PARAM__2/, endingRow);
-			var label = startingRow + ' - ' + endingRow;
-			
-			// var td = util.createE('td', {padding:'0px'});
-			var a = util.createE('a', {id:id, href:'javascript:;', title:title});
-			
-			if (util.userAgent.isIE) {
-				// fixes IE hover quirks
-				a.style.height = '1%';
-			}
-			
-			var text = util.createT(label);
-			
-			// Add the image
-			var dat = isNext ? imgDb.rowsNext : imgDb.rowsPrev;
-			var img = util.createE('img', {src:dat.src, width:dat.width, height:dat.height, title:'', alt:'', marginRight:'2px', marginLeft:'2px'});
-			
-			YAHOO.util.Event.addListener(a, 'click', report.rowNumbers.setRowRange);
-			
-			if (isNext) {
-				
-				util.chainE(div, [a, text, img]);
-			}
-			else {
-				
-				util.chainE(div, [a, img, text]);
+			var element = util.getE(shortReportElementId + ':custom_row_range:panel');
+			var showCustomRange = (element.style.display == 'none');
+			element.style.display = showCustomRange ? 'block' : 'none';
+
+			if (showCustomRange) {
+				util.focusE(shortReportElementId + ':custom_row_range:starting_row');
 			}
 		},
-		
-		buildNumberButtonsBar: function(div, shortReportElementId, startingRow, endingRow, totalRows) {
-			
-			var sequence = report.rowNumbers.sequence;
-			var lastSetRowNumber;
-			var isActive = true; // All row buttons are always active!
-			
-			for (var i = 0; i < sequence.length; i++) {
-				
-				var numberOfRows = sequence[i];
-				
-				if (numberOfRows <= totalRows) {
-					
-					lastSetRowNumber = numberOfRows;
-					// isActive = (numberOfRows != endingRow);
-					
-					report.rowNumbers.buildNumberButton(div, shortReportElementId, numberOfRows, numberOfRows, isActive);
-				}
-				else {
-					
-					// add All Rows button if appropriate
-					
-					var maxRowNumber = sequence[sequence.length - 1];
-					
-					if (totalRows > lastSetRowNumber && totalRows <= maxRowNumber) {
-	
-						report.rowNumbers.buildNumberButton(div, shortReportElementId, totalRows, totalRows, isActive);
-					}
-					
+
+		init: function(shortReportElementId, reportElementType, startingRow, endingRow, numberOfRows, totalRows, isUnknownTotalRows, numberOfRowsInTable) {
+
+			var YE = YAHOO.util.Event;
+			var theRows = [{value:10, label:10},
+							{value:20, label:20},
+							{value:50, label:50},
+							{value:100, label:100},
+							{value:200, label:200},
+							{value:500, label:500}];
+
+			var defaultNumberOfRows = '';
+
+			for (var i = 0; i < theRows.length; i++) {
+				if (theRows[i].value == numberOfRows) {
+					defaultNumberOfRows = numberOfRows;
 					break;
 				}
 			}
-			
-			//
-			// Add button to toggle manual row number editor
-			//
-			
-			var id = 'toggle_custom_row_range:' + shortReportElementId;
-			var title = langVar('lang_stats.row_numbers.custom_row_range');
-					
-			var a = util.createE('a', {id:id, href:'javascript:;', title:title});
-			var text = util.createT('[...]');
-			
-			YAHOO.util.Event.addListener(a, 'click', report.rowNumbers.toggleCustomRowRange);
-			
-			util.chainE(div, a, text);
-		},
-		
-		buildNumberButton: function(div, shortReportElementId, numberOfRows, numberOfRowsLabel, isActive) {
-			
-			// numberOfRows is always a rows sequence value, i.e. 10, 20, 40, ...
-			// numberOfRowsLabel may be the totals Row value, i.e. 43, 44, 206, ...
-			
-			var id = 'row_number_btn:' + shortReportElementId + ':' + numberOfRows;
-			// var title = 'Show row 1 - ' + numberOfRowsLabel;
-			var title = langVar('lang_stats.row_numbers.show_row_1_up_to');
-			title = title.replace(/__PARAM__1/, numberOfRowsLabel);
-			
-			// var td = util.createE('td', {padding:'0px'});
-			var a = util.createE('a', {id:id, href:'javascript:;', title:title});
-			
-			if (util.userAgent.isIE) {
-				// fixes IE hover quirks
-				a.style.height = '1%';
+
+			if (defaultNumberOfRows == '') {
+				// No number of rows which matches the default list.
+				// Add ndash as first and active row number list item
+				theRows.splice(0, 0, {value:'', label:'\u2013'});
 			}
-			
-			var text = util.createT(numberOfRowsLabel);
-			
-			if (isActive) {
-				YAHOO.util.Event.addListener(a, 'click', report.rowNumbers.setRowNumber);
-			}
-			
-			util.chainE(div, a, text);
-		},
-		
-		buildCustomRowRangeBar: function(div, shortReportElementId, startingRow, endingRow) {
-			
-			var text = util.createT(langVar('lang_stats.row_numbers.row') + ': ');
-			var id = 'custom_row_range:' + shortReportElementId + ':starting_row';
-			var input = util.createE('input', {id:id, type:'text', value:startingRow, width:'60px'});
-			var text2 = util.createT(' - ');
-			var id2 = 'custom_row_range:' + shortReportElementId + ':ending_row';
-			var input2 = util.createE('input', {id:id2, type:'text', value:endingRow, width:'60px', marginRight:'7px'});
-			var buttonId = 'custom_row_range:' + shortReportElementId + ':btn';
-			var button = util.createE('input', {id:buttonId, type:'button', value:langVar('lang_stats.btn.apply'), fontSize: '1em'});
-			
-			YAHOO.util.Event.addListener(button, 'click', report.rowNumbers.setCustomRowRange);
-			
-			util.chainE([div, text, input, text2, input2, button]);
+
+			// Populate select element.
+			util.populateSelect(shortReportElementId + ':row_numbers', theRows, 'value', 'label', defaultNumberOfRows);
+
+			YE.addListener(shortReportElementId + ':row_numbers', 'change', report.rowNumbers.setRowNumber);
+			YE.addListener([shortReportElementId + ':prev_rows_btn', shortReportElementId + ':next_rows_btn'], 'click', report.rowNumbers.setRowRange);
+			YE.addListener(shortReportElementId + ':toggle_custom_row_range', 'click', report.rowNumbers.toggleCustomRowRange);
+			YE.addListener(shortReportElementId + ':custom_row_range:btn', 'click', report.rowNumbers.setCustomRowRange);
 		}
 	},
 	
@@ -820,7 +906,7 @@ var report = {
 				//
 				
 				// alert('rowId: ' + rowId + '\ntdClassName: ' + tdClassName + '\ntr backgroundColor: ' + element.style.backgroundColor);
-				var isZoomItem = (tdClassName == 'zoom');
+				var isZoomItem = (tdClassName.indexOf('zoom') != -1);
 				var rowsDb = report.rowSelection.rowsDb;
 				var isSelect;
 				var isZoom;
